@@ -44,6 +44,12 @@ class SendCloudApiError(ApiError):
     cls_code = -9100
 
 
+class WebApiError(ApiError):
+    """
+    """
+    cls_code = -9200
+
+
 class Api(object):
 
     def fetch(self, request):
@@ -448,6 +454,27 @@ class SendCloudApi(Api):
         return "%s%s" % (api_url, api_path)
 
 
+class WebApi(Api):
+
+    TAOBAO_IP_SERVER = 'http://ip.taobao.com/service/getIpInfo.php'
+
+    def get_ip_info(self, ipaddr):
+        """根据IP地址获取详细信息，数据基于淘宝IP地址库接口
+        :param ipaddr: IP地址
+        :return: dict 地址的详细信息
+        """
+        ip_query_url = "%s?ip=%s" % (self.TAOBAO_IP_SERVER, ipaddr)
+        request = HTTPRequest(ip_query_url, method="GET", validate_cert=False)
+        resp_body = self.fetch(request)
+        ipinfo = json.loads(resp_body)
+        if not isinstance(ipinfo, dict):
+            raise WebApiError(msg="解析淘宝IP地址服务错误: Body不是一个有效的JSON字符串")
+        if ipinfo.get('code') == 0:
+            return ipinfo.get('data')
+        else:
+            raise WebApiError(msg="淘宝服务API服务返回错误。code:[%s] data:[%s]" % (ipinfo.get('code'), ipinfo.get('data')))
+
+
 if __name__ == '__main__':
     content = """尊敬的爱手艺用户您好：
 
